Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
Configuration the configuration for the server, is normally assigned via CLI on -i or --init .
type MaterializationServer ¶
type MaterializationServer struct {
Config *Configuration
Store *data.Store
// contains filtered or unexported fields
}
MaterializationServer A struct containing the server and store pointers. After creating the server struct you should call MaterializationServer.Initialize(&store) to initialize the server.
Click to show internal directories.
Click to hide internal directories.